- Add module `xoutil.future.csv`:mod:.

- Add module `xoutil.future.mimetypes`:mod:.

- Add module `xoutil.eight.urllib`:mod:.

- The module ``xoutil.iterators`` is now officially named
  `xoutil.future.itertools`:mod:.  The alias ``xoutil.iterators`` remains as a
  deprecated alias.

- Add `xoutil.future.itertools.merge`:func:.

- Add `xoutil.future.types._get_mro_attr`:func: function.

- Deprecate in `xoutil.future.types`:mod: module: ``mro_dict`` class; and the
  functions ``mro_get_value_list``, ``mro_get_full_mapping``, ``is_iterable``,
  ``is_collection``, ``is_mapping``, ``is_string_like``, ``is_scalar``,
  ``is_module``, ``are_instances``, and ``no_instances``.
